@@ -311,13 +311,9 @@ kLinesSaver::kLinesSaver( WId id ) : KScreenSaver( id ){
 	initialiseColor();
 	initialiseLines();
 	timer.start(speed);
-	connect(&timer, SIGNAL(timeout()), SLOT(slotTimeout()));
-        {
-            QPalette palette;
-            palette.setColor( backgroundRole(), Qt::black );
-            setPalette( palette );
-	    setAutoFillBackground(true);
-        }
+	connect(&timer, SIGNAL(timeout()), SLOT(update()));
+	setAttribute( Qt::WA_NoSystemBackground );
+	cleared = false;
 	show();
 }
 
@@ -363,33 +359,8 @@ void kLinesSaver::readSettings(){
     colend=config.readEntry("EndColor", QColor(Qt::black));
 }
 
-// draw next lines and erase tail
-void kLinesSaver::slotTimeout(){
-   update();
-/*
-	uint i;
-	int x1,y1,x2,y2;
-	int col=0;
-
-	lines->reset();
-    QPainter p( this );
-    p.setPen( Qt::black );
-
-	for(i=0; i<numLines; i++){
-		lines->getKoord(x1,y1,x2,y2);
-        p.drawLine( x1, y1, x2, y2 );
-		p.setPen( colors[col] );
-		col=(int)(i*colscale);
-		if(col>63) col=0;
-	}
-	lines->turn(width(), height());
-*/
-}
-
 void kLinesSaver::paintEvent(QPaintEvent *)
 {
-        setAttribute( Qt::WA_NoSystemBackground ); // Only after initial clear
-
         uint i;
         int x1,y1,x2,y2;
         int col=0;
@@ -399,6 +370,11 @@ void kLinesSaver::paintEvent(QPaintEvent *)
      QPainter p( this );
     p.setPen( Qt::black );
 
+    if (!cleared) {
+        cleared = true;
+        p.fillRect(rect(), Qt::black);
+    }
+
         for(i=0; i<numLines; i++){
                 lines->getKoord(x1,y1,x2,y2);
         p.drawLine( x1, y1, x2, y2 );
